#!/bin/bash
#
# fuss-cert-renew.sh
#
# Copyright (C) 2007 Simone Piccardi <piccardi@truelite.it>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program or from the site that you downloaded it
# from; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307   USA
#
set -e

# Defining used files, directories and program
CONF_FILE=/etc/fuss-server/fuss-server.conf
CA_DIR=/etc/fuss-server/Credentials
SCRIPT_DIR=/usr/share/fuss-server/scripts
TEMPL_DIR=/usr/share/fuss-server/templates

if [ -f /etc/ssl/certs/fuss-server-cert.pem ]; then
    echo "Starting"
else
    echo "Something wrong, cannot find certificate file"
    echo "/etc/ssl/certs/fuss-server-cert.pem"
    echo "Is really a recent fuss-server installation ?"
    exit 1
fi

if [ -f "$CONF_FILE" ]; then
    . "$CONF_FILE"
else
    echo "Something wrong, missing configuration file $CONF_FILE"
    echo "Using an older fuss-server version ?"
    exit 1
fi
export PASS="$MASTER_PASS"

if [ -f "$SCRIPT_DIR/CA.sh" ]; then
    echo "CA management script OK"
else
    echo "Something wrong, cannot find CA management script"
    echo "Using a wrong fuss-server version ?"
    exit 1
fi

if [ -f "$TEMPL_DIR/confirm" ]; then
    echo "CA template OK"
else
    echo "Something wrong, cannot find CA template data"
    echo "Using a wrong fuss-server version ?"
    exit 1
fi


if [ -d "$CA_DIR" ]; then
    # starting
    cd $CA_DIR
    mv -f newcert.pem newcertold.pem
    echo "Re-Signing server certificate"
    $SCRIPT_DIR/CA.sh -sign < $TEMPL_DIR/confirm
    cp -af /etc/ssl/certs/fuss-server-cert.pem /root/old-fuss-server-cert.pem
    cp -af newcert.pem /etc/ssl/certs/fuss-server-cert.pem
else
    echo "Something wrong, missing CA directory $CA_DIR"
    echo "Using an older fuss-server version ?"
    exit 1
fi


# restarting LDAP
/etc/init.d/slapd restart
